==> ui-framework-elements-5.1.25.jar: gen/displays/templates/WidgetSummaryMoldCard.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiOpenPage from "alexandria-ui-elements/src/displays/components/OpenPage";
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiMultiple from "alexandria-ui-elements/src/displays/components/Multiple";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import WidgetSummaryMoldCardNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import WidgetSummaryMoldCardRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class WidgetSummaryMoldCard extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new WidgetSummaryMoldCardNotifier(this);
		this.requester = new WidgetSummaryMoldCardRequester(this);
	};

	render() {
		const display = !this.state.visible ? {display:'none'} : undefined;
		const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock layout="vertical flexible" width="100.0%" height="100.0%" style={{...this.props.style,...display}}>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1965182215" layout="vertical flexible" width="400px" height="-1px" paper>
					<UiOpenPage context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1965182215.a_1166035795" title="" target="self" mode="Link" size="Large" format="h6">
					</UiOpenPage>
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1965182215.a_1052336488" layout="flexible">
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1965182215.a_1052336488.a_245949036" mode="normal">
						</UiText>
					</UiBlock>
					<UiMultiple context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1965182215.a2098887143" format="body2" multiple={{instances:"facets",arrangement:"Horizontal",noItemsMessage:"",spacing:0,editable:false,wrap:true,collapsed:false,count:{min:0,max:-1}}} mode="normal" highlighted={{text:"white",background:"#679164"}}>
					</UiMultiple>
				</UiBlock>
			</UiBlock>
		);
	}
}

export default withStyles(styles, { withTheme: true })(withSnackbar(WidgetSummaryMoldCard));
DisplayFactory.register("WidgetSummaryMoldCard", withStyles(styles, { withTheme: true })(withSnackbar(WidgetSummaryMoldCard)));

==> ui-framework-elements-5.2.12.jar: gen/displays/templates/WidgetSummaryMoldCard.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiOpenPage from "alexandria-ui-elements/src/displays/components/OpenPage";
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiMultiple from "alexandria-ui-elements/src/displays/components/Multiple";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import WidgetSummaryMoldCardNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import WidgetSummaryMoldCardRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class WidgetSummaryMoldCard extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new WidgetSummaryMoldCardNotifier(this);
		this.requester = new WidgetSummaryMoldCardRequester(this);
	};

	render() {
		const display = !this.state.visible ? {display:'none'} : undefined;
		const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock layout="vertical flexible" width="100.0%" height="100.0%" style={{...this.props.style,...display}}>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1737494084" layout="vertical flexible" width="400px" height="-1px" paper>
					<UiOpenPage context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1737494084.a2001535408" title="" target="self" mode="Link" size="Large" format="h6">
					</UiOpenPage>
					<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1737494084.a499482258" layout="flexible">
						<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1737494084.a499482258.a_18260905" mode="normal">
						</UiText>
					</UiBlock>
					<UiMultiple context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_1737494084.a1509346628" format="body2" multiple={{instances:"facets",arrangement:"Horizontal",noItemsMessage:"",spacing:0,editable:false,wrap:true,collapsed:false,count:{min:0,max:-1}}} mode="normal" highlighted={{text:"white",background:"#679164"}}>
					</UiMultiple>
				</UiBlock>
			</UiBlock>
		);
	}
}

export default withStyles(styles, { withTheme: true })(withSnackbar(WidgetSummaryMoldCard));
DisplayFactory.register("WidgetSummaryMoldCard", withStyles(styles, { withTheme: true })(withSnackbar(WidgetSummaryMoldCard)));
